==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/k8s/resource_k8s_wg/main.tf <==
/*
Пример использования
Получение информации о группе воркеров кластера Kubernetes(k8s)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}


resource "dynamix_k8s_wg" "wg" {
  #id экземпляра k8s
  #обязательный параметр
  #тип - целое число
  k8s_id = 1234

  #имя worker group
  #обязательный параметр
  #тип - строка
  name = "workers-2"

  #количество worker node для создания
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  num = 2

  #количество cpu для 1 worker node
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  cpu = 1

  #количество RAM для одной worker node в Мбайтах
  #опциональный параметр
  #тип - целое число
  #по-умолчанию - 1024
  ram = 1024

  #размер загрузочного диска для worker node, в Гбайтах
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 0
  #если установлен параметр 0, то размер диска будет равен размеру образа
  disk = 10

  #Перечень аргументов для cloud-init для виртуальных машин worker групп
  #опциональный параметр
  #тип - файл с форматом в виде yaml
  #используется при создании и обновлении ресурса
  cloud_init = file("initconfig.tftpl")
}


output "test_wg" {
  value = dynamix_k8s_wg.wg
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/k8s/resource_k8s_wg/main.tf <==
/*
Пример использования
Получение информации о группе воркеров кластера Kubernetes(k8s)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}


resource "dynamix_k8s_wg" "wg" {
  #id экземпляра k8s
  #обязательный параметр
  #тип - целое число
  k8s_id = 1234

  #имя worker group
  #обязательный параметр
  #тип - строка
  name = "workers-2"

  #количество worker node для создания
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  num = 2

  #тип эмулируемой системы worker nodes
  #опциональный параметр
  #тип - строка
  worker_chipset = "i440fx"

  #количество cpu для 1 worker node
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  cpu = 1

  #тип эмулируемой системы worker группы
  #опциональный параметр
  #тип - строка
  chipset = "i440fx"

  #количество RAM для одной worker node в Мбайтах
  #опциональный параметр
  #тип - целое число
  #по-умолчанию - 1024
  ram = 1024

  #размер загрузочного диска для worker node, в Гбайтах
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 0
  #если установлен параметр 0, то размер диска будет равен размеру образа
  disk = 10

  #id SEP'а для создания загрузочных дисков для группы worker node по умолчанию,
  #если не указан, используется sep_id образа
  #опциональный параметр
  #тип - целое число
  worker_sep_id = 1

  #pool для использования, если установлен worker_sep_id, если не указан, выбирается системой
  #опциональный параметр
  #тип - строка
  worker_sep_pool = "pool"

  #Перечень аргументов для cloud-init для виртуальных машин worker групп
  #опциональный параметр
  #тип - файл с форматом в виде yaml
  #используется при создании и обновлении ресурса
  cloud_init = file("initconfig.tftpl")
}


output "test_wg" {
  value = dynamix_k8s_wg.wg
}
